//
//  WeatherForecast.m
//  Weather
//
//  Created by Alasdair Allan on 14/12/2012.
//  Copyright (c) 2012 Babilim Light Industries. All rights reserved.
//

#import "WeatherForecast.h"
#import "MainViewController.h"
#import "XPathQuery.h"


@implementation WeatherForecast

- (void)queryServiceWithState:(NSString *)state andCity:(NSString *)city withParent:(UIViewController *)controller {
    viewController = (MainViewController *)controller;
    responseData = [NSMutableData data];
    apiKey = @"60d7b82d58e9c065";
    
    NSString *url = [NSString stringWithFormat:@"http://api.wunderground.com/api/%@/conditions/q/%@/%@.xml", apiKey, state, city];
    theURL = [NSURL URLWithString:url];
    NSURLRequest *request = [NSURLRequest requestWithURL:theURL];
    [[NSURLConnection alloc] initWithRequest:request delegate:self];
    
}

#pragma mark NSURLConnection Delegate Methods

- (NSURLRequest *)connection:(NSURLConnection *)connection willSendRequest:(NSURLRequest *)request redirectResponse:(NSURLResponse *)redirectResponse {
    @autoreleasepool {
        theURL = [request URL];
    }
    return request;
}

- (void)connection:(NSURLConnection *)connection didReceiveResponse:(NSURLResponse *)response {
    [responseData setLength:0];
}

- (void)connection:(NSURLConnection *)connection didReceiveData:(NSData *)data {
    [responseData appendData:data];
}

- (void)connection:(NSURLConnection *)connection didFailWithError:(NSError *)error {
    NSLog( @"Error = %@", error );
}

// Retrieves the content of an XML node, such as the temperature, wind,
// or humidity in the weather report.
//
- (NSString *)fetchContent:(NSArray *)nodes {
    NSString *result = @"";
    for ( NSDictionary *node in nodes ) {
        for ( id key in node ) {
            if( [key isEqualToString:@"nodeContent"] ) {
                result = [node objectForKey:key];
            }
        }
    }
    return result;
}

// For nodes that contain more than one value we are interested in,
// this method fills an NSMutableArray with the values it finds.
// For example, the forecast returns four days, so there will be
// an array with four day names, an array with four forecast icons,
// and so forth.
//
- (void) populateArray:(NSMutableArray *)array fromNodes:(NSArray*)nodes {
    for ( NSDictionary *node in nodes ) {
        for ( id key in node ) {
            if( [key isEqualToString:@"nodeContent"] ) {
                [array addObject:[node objectForKey:key]];
            }
        }
    }
}

- (void)connectionDidFinishLoading:(NSURLConnection *)connection {
    //NSString *content = [[NSString alloc] initWithBytes:[responseData bytes] length:[responseData length] encoding:NSUTF8StringEncoding];
    //NSLog( @"Data = %@", content );
    
    NSString *xpathQueryString;
    NSArray *nodes;
    
    xpathQueryString = @"//response/current_observation/display_location/full";
    nodes = PerformXMLXPathQuery(responseData, xpathQueryString);
    self.location = [self fetchContent:nodes];
    NSLog(@"location = %@", self.location);

    xpathQueryString = @"//response/current_observation/icon_url";
    nodes = PerformXMLXPathQuery(responseData, xpathQueryString);
    self.icon = [self fetchContent:nodes];
    NSLog(@"icon = %@", self.icon);

    xpathQueryString = @"//response/current_observation/weather";
    nodes = PerformXMLXPathQuery(responseData, xpathQueryString);
    self.condition = [self fetchContent:nodes];
    NSLog(@"condition = %@", self.condition);
 
    xpathQueryString = @"//response/current_observation/temp_c";
    nodes = PerformXMLXPathQuery(responseData, xpathQueryString);
    self.centigrade = [self fetchContent:nodes];
    NSLog(@"condition = %@", self.centigrade);

    xpathQueryString = @"//response/current_observation/temp_f";
    nodes = PerformXMLXPathQuery(responseData, xpathQueryString);
    self.fahrenheit = [self fetchContent:nodes];
    NSLog(@"condition = %@", self.fahrenheit);
    
    xpathQueryString = @"//response/current_observation/relative_humidity";
    nodes = PerformXMLXPathQuery(responseData, xpathQueryString);
    self.humidity = [self fetchContent:nodes];
    NSLog(@"condition = %@", self.humidity);
    
    xpathQueryString = @"//response/current_observation/wind_string";
    nodes = PerformXMLXPathQuery(responseData, xpathQueryString);
    self.wind = [self fetchContent:nodes];
    NSLog(@"condition = %@", self.wind);
     
    [viewController updateView];

}

@end
